clear all
set more off

global datadir = "C:\Users\17786\OneDrive\Desktop\Data" // Specify directory where main folder is
global figures = "${datadir}\Figures" // Specify directory where figures will be saved
global raw_data = "${datadir}\Raw data" // Directory where raw data is stored
global adobase = "${datadir}\ado" // Directory where additional ado programs are stored needed for replication

// Replacing the PERSONAL, PLUS and SITE directories where additional ado programs are located
sysdir set PERSONAL ${adobase}
sysdir set PLUS ${adobase}
sysdir set SITE ${adobase}

cd ${datadir}

********* Generating Wage at Home *****************

import excel "${raw_data}\Occupation data on wages.xlsx", sheet("Sheet1") firstrow clear

summ Workfromhome, detail
local cutoff = r(p90)
// In those occupations, where people work from home 0.19 of time are called those where home work is preferred to market work
gen dummy_home = 0 
replace dummy_home = 1 if Workfromhome>= `cutoff'

gen log_Weekly_market_wages = log(Weekly_market_wages)

gen rel_wage = (Workfromhome-`cutoff')
gen log_Weekly_wages_home = log_Weekly_market_wages + rel_wage

gen Weekly_wages_home = exp(log_Weekly_wages_home)
gsort - rel_wage

drop log_Weekly_wages_home log_Weekly_market_wages

summ Risk_index_factor if dummy_home == 0
local med = r(mean)

gen risk_prop = (Risk_index_factor - `med')/`med' if dummy_home == 0
replace risk_prop = -1 if dummy_home == 1

gen Relativehomewage = 1 + rel_wage

***************** Generating Figures 1, 3 and 9 ******************
egen ID_str = rank(Relativehomewage)
labmask ID_str, values(NOC_short)

sort ID_str

su n_workers, detail
gen workers_percent = (n_workers*100)/`r(sum)'

replace Workfromhome = Workfromhome*100
replace Relativehomewage = Relativehomewage*100

gen Workfromhome_neg = -Workfromhome
gen Risk_index_neg = -Risk_index_factor

* Figure 1 - Occupations and work from home
splitvallabels ID_str, length(46)
twoway (bar Workfromhome ID_str, horizontal ytitle(" ") barwidth(1) fcolor(white) lcolor(black)) || ///
(bar workers_percent ID_str, horizontal ytitle(" ") barwidth(1) fcolor(gs6) lcolor(black)), ///
ylabel(`r(relabel)', labsize(*.6) angle(0) nogrid notick) graphregion(color(white)) bgcolor(white) ///
legend(order(1 "Working from home" 2 "Occupation Shares") position(4) ring(0) size(small) rows(2) cols(1) region(lcolor(white))) ///
xlabel(0(5)30) xtitle("Percent") ysc(noline)
graph export "${figures}\Figure_1.pdf", replace

* Figure 3 - Estimated Relative Home Wage Schedule
splitvallabels ID_str, length(46)
twoway (bar Workfromhome_neg ID_str, horizontal ytitle(" ") barwidth(1) fcolor(gs6) lcolor(black) ) || ///
(bar Relativehomewage ID_str, horizontal ytitle(" ") barwidth(1) fcolor(white) lcolor(black)), ///
ylabel(`r(relabel)', labsize(*.6) angle(0) nogrid) graphregion(color(white)) bgcolor(white) ///
legend(order(1 "Working from home" 2 "Relative Home Wage") position(6) ring(1) size(medsmall) cols(2) rows(1) span region(lcolor(white))) ///
xlabel(-35 "35" -20 "20" 0 "0" 25 "25" 50 "50" 75 "75" 100 "100") xtitle("Percent") 
graph export "${figures}\Figure_3.pdf", replace

* Figure 9 - Indices by Occupations
gen ID_str_mkt = ID_str if dummy_home==0
labmask ID_str_mkt, values(NOC_short) 

splitvallabels ID_str_mkt, length(46)
twoway (bar Relativehomewage ID_str_mkt, horizontal ytitle(" ") barwidth(1) fcolor(white) lcolor(black)) || ///
(bar Risk_index_factor ID_str_mkt , horizontal ytitle(" ") barwidth(1) fcolor(gs6) lcolor(black) ), ///
ylabel(`r(relabel)', labsize(*.6) angle(0) nogrid notick) graphregion(color(white)) bgcolor(white) ///
legend(order(1 "Relative Home Wage" 2 "VSE Risk Factor" ) position(6) ring(1) rows(1) cols(2) size(small) region(lcolor(white))) ///
xlabel(0(25)100) xtitle("Percent") ysc(noline)
graph export "${figures}\Figure_9.pdf", replace

************* Generating Figure 2 which needs a different datafile ***************

import excel "${raw_data}\Occupation Employment.xlsx", sheet("Sheet1") firstrow clear

egen ID_str = rank(Workfromhome)
labmask ID_str, values(NOC_short)

sort ID_str

su Feb, detail
gen workers_percent = Feb/`r(sum)'

gen change_apr = (Apr - Feb)*(100*workers_percent)/Feb
gen change_jun = (Jun - Apr)*(100*workers_percent)/Apr


* Figure 2 - Changes in employment in occupations
splitvallabels ID_str, length(46)
twoway (dropline change_apr ID_str, horizontal ytitle(" ") mcolor(gs7) msymbol(o) msize(med) lpattern(dash) lcolor(black)) || ///
(dropline change_jun ID_str, horizontal ytitle(" ") mcolor(black) msymbol(dh) msize(med) lpattern(solid) lcolor(gs7)), ///
ylabel(`r(relabel)', labsize(*.6) angle(0) nogrid notick) graphregion(color(white)) bgcolor(white) ///
legend(order(1 "Feb-Apr" 2 "Apr-June") position(4) ring(0) size(small) rows(2) cols(1) region(lcolor(white))) ///
xlabel(-2(1)3) xtitle("Percent") ysc(noline) xline(0, lcolor(black))
graph export "${figures}\Figure_2.pdf", replace
