clear all
set more off

************* Generating Figure 8 *************************

global datadir = "C:\Users\17786\OneDrive\Desktop\Data" // Specify directory where main folder is
global figures = "${datadir}\Figures" // Specify directory where figures will be saved
global raw_data = "${datadir}\Raw data" // Directory where raw data is stored
global adobase = "${datadir}\ado" // Directory where additional ado programs are stored needed for replication

// Replacing the PERSONAL, PLUS and SITE directories where additional ado programs are located
sysdir set PERSONAL ${adobase}
sysdir set PLUS ${adobase}
sysdir set SITE ${adobase}

cd ${datadir}

import excel "${datadir}\endogenous_infections.xlsx", sheet("Sheet1") firstrow clear

replace I_endog = I_endog*100
replace S_endog = S_endog*100
replace R_endog = R_endog*100
replace D_endog = D_endog*100

replace I_endog_low = I_endog_low*100
replace S_endog_low = S_endog_low*100
replace R_endog_low = R_endog_low*100
replace D_endog_low = D_endog_low*100

save "infections_model", replace


************************************ Creating graph for British Columbia *******************************
import excel "${raw_data}\Deaths data.xlsx", sheet("BC") firstrow clear

tsset date
format date %td
tsfill
su Population
replace Population = r(mean) // replacing some of the missing values

gen inf_1 = F18.deaths*100 // IFR of 1%
gen inf_5 = (F18.deaths*100)/0.5 // IFR of 0.5%
gen inf_2_5 = (F18.deaths*100)/0.25 // IFR of 0.25%

gen int week_num = floor((date-td(17feb2020))/7) + 1
collapse (max) date deaths inf_1 inf_2_5 inf_5 Population, by( week_num)
drop if week_num<0

tsset week_num
gen inf_rate_1 = (inf_1-L1.inf_1)*100/Population
gen inf_rate_5 = (inf_5-L1.inf_5)*100/Population
gen inf_rate_2_5 = (inf_2_5-L1.inf_2_5)*100/Population
gen death_rate = deaths*100/Population

label var inf_rate_1 "1% IFR"
label var inf_rate_5 "0.5% IFR"
label var inf_rate_2_5 "0.25% IFR"
label var death_rate "Deaths - Data"

rename week_num Week
drop if Week<1

merge 1:1 Week using "infections_model"
drop if _merge==2
drop _merge

twoway (line inf_rate_1 Week, lwidth(medium) lpattern(longdash) lcolor(gs7) ) ///
(line inf_rate_5 Week, lcolor(black) lwidth(thick) lpattern(dash) lcolor(gs5)) (line inf_rate_2_5 Week, lwidth(medium) lpattern(shortdash) lcolor(gs3)) ///
(line I_endog Week, lwidth(medium) lpattern(solid) lcolor(black) ) (line I_endog_low Week, lwidth(medthick) lpattern(dash_dot) lcolor(gs5) ), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Infection Rate", color(black) size(medlarge)) legend(off) xtitle("Weeks", size(medium)) ytitle("") 
graph save "bc_inf_cf.gph", replace
twoway (line death_rate Week, lwidth(thick) lpattern(longdash_dot) lcolor(gs6)) (line D_endog Week, lwidth(medium) lpattern(solid) lcolor(black)) ///
(line D_endog_low Week, lwidth(medthick) lpattern(dash_dot)  lcolor(gs3)), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Death Rate", color(black) size(medlarge)) legend(off) xtitle("Weeks", size(medium)) ytitle("") 
graph save "bc_deaths_cf.gph", replace

graph combine "bc_deaths_cf.gph" "bc_inf_cf.gph" , saving(bc_counterfactual, replace) graphregion(color(white)) title("British Columbia", size(medium) color(black)) imargin(tiny)



************************************ Creating graphs for Canada *******************************
import excel "${raw_data}\Deaths data.xlsx", sheet("Canada") firstrow clear

tsset date
format date %td
tsfill
su Population
replace Population = r(mean) // replacing some of the missing values

gen inf_1 = F18.deaths*100 // IFR of 1%
gen inf_5 = (F18.deaths*100)/0.5 // IFR of 0.5%
gen inf_2_5 = (F18.deaths*100)/0.25 // IFR of 0.25%

gen int week_num = floor((date-td(17feb2020))/7) + 1
collapse (max) date deaths inf_1 inf_2_5 inf_5 Population, by( week_num)
drop if week_num<0

tsset week_num
gen inf_rate_1 = (inf_1-L1.inf_1)*100/Population
gen inf_rate_5 = (inf_5-L1.inf_5)*100/Population
gen inf_rate_2_5 = (inf_2_5-L1.inf_2_5)*100/Population
gen death_rate = deaths*100/Population

label var inf_rate_1 "1% IFR"
label var inf_rate_5 "0.5% IFR"
label var inf_rate_2_5 "0.25% IFR"
label var death_rate "Deaths - Data"

rename week_num Week
drop if Week<1

merge 1:1 Week using "infections_model"
drop if _merge==2
drop _merge

twoway (line inf_rate_1 Week, lwidth(medium) lpattern(longdash) lcolor(gs7) ) ///
(line inf_rate_5 Week, lcolor(black) lwidth(thick) lpattern(dash) lcolor(gs5)) (line inf_rate_2_5 Week, lwidth(medium) lpattern(shortdash) lcolor(gs3)) ///
(line I_endog Week, lwidth(medium) lpattern(solid) lcolor(black) ) (line I_endog_low Week, lwidth(medthick) lpattern(dash_dot) lcolor(gs5) ), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Infection Rate", color(black) size(medlarge)) legend(off) xtitle("Weeks", size(medium)) ytitle("") 
graph save "can_inf_cf.gph", replace
twoway (line death_rate Week, lwidth(thick) lpattern(longdash_dot) lcolor(gs6)) (line D_endog Week, lwidth(medium) lpattern(solid) lcolor(black)) ///
(line D_endog_low Week, lwidth(medthick) lpattern(dash_dot)  lcolor(gs3)), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Death Rate", color(black) size(medlarge)) legend(off) xtitle("Weeks", size(medium)) ytitle("") 
graph save "can_deaths_cf.gph", replace

graph combine "can_deaths_cf.gph" "can_inf_cf.gph" , saving(can_counterfactual, replace) graphregion(color(white)) title("Canada", size(medium) color(black)) imargin(tiny)



******************************** US figure *******************************************************

import excel "${raw_data}\Deaths data.xlsx", sheet("US") firstrow clear

tsset date
format date %td
tsfill
su Population
replace Population = r(mean) // replacing some of the missing values

gen inf_1 = F18.deaths*100 // IFR of 1%
gen inf_5 = (F18.deaths*100)/0.5 // IFR of 0.5%
gen inf_2_5 = (F18.deaths*100)/0.25 // IFR of 0.25%

gen int week_num = floor((date-td(10feb2020))/7) + 1

collapse (max) date deaths inf_1 inf_2_5 inf_5 Population, by( week_num)
drop if week_num<0

tsset week_num
gen inf_rate_1 = (inf_1-L1.inf_1)*100/Population
gen inf_rate_5 = (inf_5-L1.inf_5)*100/Population
gen inf_rate_2_5 = (inf_2_5-L1.inf_2_5)*100/Population
gen death_rate = deaths*100/Population

label var inf_rate_1 "1% IFR"
label var inf_rate_5 "0.5% IFR"
label var inf_rate_2_5 "0.25% IFR"
label var death_rate "Deaths - Data"

rename week_num Week
drop if Week<1

merge 1:1 Week using "infections_model"
drop if _merge==2
drop _merge

twoway (line inf_rate_1 Week, lwidth(medium) lpattern(longdash) lcolor(gs7) ) ///
(line inf_rate_5 Week, lcolor(black) lwidth(thick) lpattern(dash) lcolor(gs5)) (line inf_rate_2_5 Week, lwidth(medium) lpattern(shortdash) lcolor(gs3)) ///
(line I_endog Week, lwidth(medium) lpattern(solid) lcolor(black) ) (line I_endog_low Week, lwidth(medthick) lpattern(dash_dot) lcolor(gs5) ), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Infection Rate", color(black) size(medlarge)) legend( order(1 2 3) label(1 "1% IFR") label(2 "0.5% IFR") label(3 "0.25% IFR") rows(1) cols(3) ring(1) position(6) size(medsmall) span region(lcolor(white)) ) xtitle("Weeks", size(medium)) ytitle("") 
graph save "us_inf_cf.gph", replace
twoway (line death_rate Week, lwidth(thick) lpattern(longdash_dot) lcolor(gs6)) (line D_endog Week, lwidth(medium) lpattern(solid) lcolor(black)) ///
(line D_endog_low Week, lwidth(medthick) lpattern(dash_dot)  lcolor(gs3)), ///
graphregion(color(white)) bgcolor(white) xsca(titlegap(*5)) ylabel(, labsize(medsmall) nogrid) xlabel( 1(10)51, labsize(medsmall) nogrid) ///
title("Death Rate", color(black) size(medlarge)) legend( label(1 "Data") label(2 "Model") label(3 "Model,adjust")  rows(1) cols(3) ring(1) position(6) size(medsmall) span region(lcolor(white))) xtitle("Weeks", size(medium)) ytitle("") 
graph save "us_deaths_cf.gph", replace

graph combine "us_deaths_cf.gph" "us_inf_cf.gph" , saving(us_counterfactual, replace) graphregion(color(white)) title("United States", size(medium) color(black)) imargin(tiny)

***************** Combining Graphs for British Columbia, Canada and United States **************************************
graph combine "bc_counterfactual.gph" "can_counterfactual.gph" "us_counterfactual.gph", rows(3) graphregion(color(white)) ///
ysize(7.75) xsize(5.15) iscale(.65)
graph export "${figures}\Figure_8.pdf", as(pdf) replace
